<?php

namespace com\fwdekker\deathnotifier;

use com\fwdekker\deathnotifier\validator\InvalidInputException;


/**
 * An action that can be performed in response to a request from the user.
 */
abstract class Action
{
    /**
     * Performs the action.
     *
     * The specific input and output requirements should be specified and enforced by the implementation.
     *
     * @param array<int|string, mixed> $inputs the inputs to perform the action with
     * @return mixed the requested data; may be `null`
     * @throws InvalidInputException if any of the inputs is invalid
     * @throws UnexpectedException if the action could not be performed even though the inputs are valid
     */
    abstract function handle(array $inputs): mixed;
}
