<?php

namespace com\fwdekker\deathnotifier;

use InvalidArgumentException;


/**
 * The application's configuration, read lazily from configuration files.
 *
 * Contains global state, but that's fine since it's read-only.
 */
// TODO: Override dynamically from tests
class Config
{
    /**
     * @var array<string, mixed>|null the application's configuration, or `null` if it has not been read yet
     */
    private static ?array $config = null;


    /**
     * Returns the application's configuration.
     *
     * @return array<string, mixed> the application's configuration
     */
    public static function get(): array
    {
        if (self::$config === null)
            self::$config = self::read_config();

        return self::$config;
    }


    /**
     * Reads the configuration file and overrides it with the user's custom values.
     *
     * @return array<string, mixed> the application's configuration
     */
    private static function read_config(): array
    {
        // TODO: Check permissions, return `null` if too permissive
        $config = parse_ini_file("config.default.ini.php", process_sections: true, scanner_mode: INI_SCANNER_TYPED);
        if ($config === false) throw new InvalidArgumentException("Invalid `config.default.ini.php` file.");

        if (file_exists("config.ini.php")) {
            $config_custom = parse_ini_file("config.ini.php", process_sections: true, scanner_mode: INI_SCANNER_TYPED);
            if ($config_custom === false) throw new InvalidArgumentException("Invalid `config.ini.php` file.");

            $config = array_replace_recursive($config, $config_custom);
        }

        return $config;
    }
}
