<?php

namespace com\fwdekker\deathnotifier\validator;


/**
 * Validates that the input is an email address.
 */
class IsEmailRule extends Rule
{
    /**
     * Validates that the input is an email address.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input is an email address
     * @throws InvalidInputException if the checked input is not set, is not a string, or is not an email address
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]) || !is_string($inputs[$key]) || !filter_var($inputs[$key], FILTER_VALIDATE_EMAIL))
            throw new InvalidInputException($this->override_message ?? "Enter a valid email address.", $key);
    }
}
