<?php

namespace com\fwdekker\deathnotifier\validator;


/**
 * Validates that the input has the specified value.
 */
class IsEqualToRule extends Rule
{
    /**
     * @var string the required value
     */
    private readonly string $expected;


    /**
     * Constructs a new `IsEqualToRule`.
     *
     * @param string $expected the value that checked values should be equal to
     * @param string|null $override_message the message to return if the rule does not apply to some input. If `null`,
     * the rule implementation can choose an appropriate message
     */
    public function __construct(string $expected, ?string $override_message = null)
    {
        parent::__construct($override_message);

        $this->expected = $expected;
    }


    /**
     * Validates that the input has the specified value.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input equals {@see $expected}
     * @throws InvalidInputException if the checked input is not set or does not equal {@see $expected}
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]) || $inputs[$key] !== $this->expected)
            throw new InvalidInputException(
                $this->override_message ?? "Input '$key' should equal '$this->expected'.",
                $key
            );
    }
}
