<?php

namespace com\fwdekker\deathnotifier\validator;


/**
 * Validates that the input is a string.
 */
class IsStringRule extends Rule
{
    /**
     * Validates that the input is a string.
     *
     * @param array<int|string, mixed> $inputs the list of inputs in which the value at {@see $key} should be checked
     * @param string $key the key in {@see $inputs} of the input to check
     * @return void if the checked input is a string
     * @throws InvalidInputException if the checked input is not a string
     */
    public function check(array $inputs, string $key): void
    {
        if (!isset($inputs[$key]) || !is_string($inputs[$key]))
            throw new InvalidInputException(
                $this->override_message ?? "Field '" . htmlentities($key) . "' must be a string.",
                $key
            );
    }
}
