<?php

namespace com\fwdekker\deathnotifier\validator;

use com\fwdekker\deathnotifier\IllegalArgumentError;


/**
 * A {@see RuleSet} specifically to validate the current session.
 */
class SessionRuleSet extends RuleSet
{
    /**
     * Constructs a new `RuleSet`.
     *
     * @param bool $validate_logged_in `true` if and only if this rule set should validate that the user is logged in
     * @param bool $validate_logged_out `true` if and only if this rule set should validate that the user is logged out
     */
    public function __construct(bool $validate_logged_in = false,
                                bool $validate_logged_out = false)
    {
        if ($validate_logged_in && $validate_logged_out)
            throw new IllegalArgumentError("Cannot require that user is both logged in and logged out.");

        $rules = [];
        if ($validate_logged_in)
            $rules["uuid"] = [new IsSetRule("You must be logged in to perform this action.")];
        if ($validate_logged_out)
            $rules["uuid"] = [new IsNotSetRule("You must be logged out to perform this action.")];

        parent::__construct($rules);
    }
}
